/***************************************************************************
                          dcsplash.h  -  description
                             -------------------
    begin                : Fre Apr 12 2002
    copyright            : (C) 2002 by Mathias Küster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DCSPLASH_H
#define DCSPLASH_H

/**
  *@author Mathias Küster
  */

#include <qwidget.h>
#include <qevent.h>

#include "DCDialogSplash.h"

class DCSplash : public QWidget, public Ui::DCDialogSplash  {
Q_OBJECT

public: 
	/** construtor */
	DCSplash( QWidget * parent = 0 );
	/** destructor */
	virtual ~DCSplash();

protected:
	/** */
	virtual void mouseDoubleClickEvent( QMouseEvent * event );
	/** */
	virtual void mousePressEvent( QMouseEvent * event );
	/** */
	virtual void mouseReleaseEvent( QMouseEvent * event );
};

#endif
